@@ -139,7 +139,7 @@ class LoopTestRunner(threading.Thread):
 
 
     def run(self):
-        """Run a test in loop during."""
+        """Run a test in loop."""
         while (running()):
             test_result = unittest.TestResult()
             self.test.clearContext()
@@ -237,12 +237,12 @@ class BenchRunner:
             trace('-' * (len(text) - 1) + "\n\n")
             monitor_key = '%s:%s:%s' % (self.method_name, cycle, cvus)
             self.test.setUpCycle()
-            self.startMonitor(monitor_key)
+            self.startMonitors(monitor_key)
             self.startThreads(cycle, cvus)
             self.logging()
             #self.dumpThreads()
             self.stopThreads()
-            self.stopMonitor(monitor_key)
+            self.stopMonitors(monitor_key)
             cycle += 1
             self.test.tearDownCycle()
             t_stop = time.time()
@@ -347,7 +347,7 @@ class BenchRunner:
             trace(stack + '\n')
 
 
-    def startMonitor(self, monitor_key):
+    def startMonitors(self, monitor_key):
         """Start monitoring on hosts list."""
         if not self.monitor_hosts:
             return
@@ -365,7 +365,7 @@ class BenchRunner:
         self.monitor_hosts = monitor_hosts
 
 
-    def stopMonitor(self, monitor_key):
+    def stopMonitors(self, monitor_key):
         """Stop monitoring and save xml result."""
         if not self.monitor_hosts:
             return
@@ -384,7 +384,7 @@ class BenchRunner:
 
     def logr(self, message):
         """Log to the test result file."""
-        self.test.logr(message, force=True)
+        self.test._logr(message, force=True)
 
     def logr_open(self):
         """Start logging tag."""
@@ -407,11 +407,11 @@ class BenchRunner:
                   'log_xml': self.result_path,}
         for (host, port, desc) in self.monitor_hosts:
             config[host] = desc
-        self.test.open_result_log(**config)
+        self.test._open_result_log(**config)
 
     def logr_close(self):
         """Stop logging tag."""
-        self.test.close_result_log()
+        self.test._close_result_log()
 
     def __repr__(self):
         """Display bench information."""
@@ -472,7 +472,12 @@ def main():
                       help="Startup delay between thread.")
     parser.add_option("", "--no-color", action="store_true",
                       help="Monochrome output.")
-
+    parser.add_option("", "--accept-invalid-links", action="store_true",
+                      help="Do not fail if css/image links are "
+                      "not reachable.")
+    parser.add_option("", "--simple-fetch", action="store_true",
+                      help="Don't load additional links like css "
+                      "or images when fetching an html page.")
     options, args = parser.parse_args()
     if len(args) != 2:
         parser.error("incorrect number of arguments")
