@@ -15,7 +15,7 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 # 02111-1307, USA.
 #
-"""FunkLoad Test Case using Richard Jones' webunit.
+"""FunkLoad test case using Richard Jones' webunit.
 
 $Id: FunkLoadTestCase.py 24757 2005-08-31 12:22:19Z bdelbosc $
 """
@@ -23,6 +23,7 @@ import os
 import sys
 import time
 import re
+from warnings import warn
 from socket import error as SocketError
 from types import ListType
 from datetime import datetime
@@ -39,7 +40,7 @@ from webunit.webunittest import WebTestCase, HTTPError
 
 import PatchWebunit
 from utils import get_default_logger, mmn_is_bench, mmn_decode
-from utils import recording, thread_sleep, is_html, get_version
+from utils import recording, thread_sleep, is_html, get_version, trace
 from xmlrpclib import ServerProxy
 
 _marker = []
@@ -48,15 +49,15 @@ _marker = []
 # Classes
 #
 class FunkLoadTestCase(unittest.TestCase):
-    """Conducts a functional test of a Web-enabled HTTP application."""
+    """Unit test with browser and configuration capabilties."""
     # ------------------------------------------------------------
     # Initialisation
     #
     def __init__(self, methodName='runTest', options=None):
         """Initialise the test case.
 
-        Extract the testname from the methodName if
-        method is encoded like 'methodName:testName'."""
+        Note that methodName is encoded in bench mode to provide additional
+        information like thread_id, concurrent virtual users..."""
         if mmn_is_bench(methodName):
             self.in_bench_mode = True
         else:
@@ -69,12 +70,27 @@ class FunkLoadTestCase(unittest.TestCase):
         self._response = None
         self.options = options
         self._funkload_init()
-        self.dumping = getattr(options, 'dump_dir', False) and True
-        self.viewing = getattr(options, 'firefox_view', False)
-        if self.viewing and not self.dumping:
+        self._dump_dir = getattr(options, 'dump_dir', None)
+        self._dumping =  self._dump_dir and True or False
+        self._viewing = getattr(options, 'firefox_view', False)
+        self._accept_invalid_links = getattr(options, 'accept_invalid_links',
+                                             False)
+        self._simple_fetch = getattr(options, 'simple_fetch', False)
+        self._stop_on_fail = getattr(options, 'stop_on_fail', False)
+        if self._viewing and not self._dumping:
             # viewing requires dumping contents
-            self.dumping = True
-            self.options.dump_dir = mkdtemp('_funkload')
+            self._dumping = True
+            self._dump_dir = mkdtemp('_funkload')
+        self._loop_mode = getattr(options, 'loop_steps', False)
+        if self._loop_mode:
+            if options.loop_steps.count(':'):
+                steps = options.loop_steps.split(':')
+                self._loop_steps = range(int(steps[0]), int(steps[1]))
+            else:
+                self._loop_steps = [int(options.loop_steps)]
+            self._loop_number = options.loop_number
+            self._loop_recording = False
+            self._loop_records = []
 
     def _funkload_init(self):
         """Initialize a funkload test case using a configuration file."""
@@ -120,11 +136,10 @@ class FunkLoadTestCase(unittest.TestCase):
                                         quiet=True))
         #self.logd('# FunkLoadTestCase._funkload_init done')
 
-
     def clearContext(self):
         """Resset the testcase."""
         self._browser.clearContext()
-        self._browser.css = {}                   # css cache
+        self._browser.css = {}
         self._browser.history = []
         self._browser.extra_headers = []
         self.step_success = True
@@ -142,61 +157,16 @@ class FunkLoadTestCase(unittest.TestCase):
 
 
 
-    #------------------------------------------------------------
-    # configuration file utils
-    #
-    def conf_get(self, section, key, default=_marker, quiet=False):
-        """Return an entry from the options or configuration file."""
-        # check for a command line options
-        opt_key = '%s_%s' %(section, key)
-        opt_val = getattr(self.options, opt_key, None)
-        if opt_val:
-            #print('[%s] %s = %s from options.' % (section, key, opt_val))
-            return opt_val
-        # check for the configuration file if opt val is None
-        # or nul
-        try:
-            val = self._config.get(section, key)
-        except (NoSectionError, NoOptionError):
-            if not quiet:
-                self.logi('[%s] %s not found' % (section, key))
-            if default is _marker:
-                raise
-            val = default
-        #print('[%s] %s = %s from config.' % (section, key, val))
-        return val
-
-
-    def conf_getInt(self, section, key, default=_marker, quiet=False):
-        """Return an integer from th econfiguration file."""
-        return int(self.conf_get(section, key, default, quiet))
-
-    def conf_getFloat(self, section, key, default=_marker, quiet=False):
-        """Return a float from th econfiguration file."""
-        return float(self.conf_get(section, key, default, quiet))
-
-    def conf_getList(self, section, key, default=_marker, quiet=False):
-        """Return a list from th econfiguration file."""
-        value = self.conf_get(section, key, default, quiet)
-        if value is default:
-            return value
-        if value.count(':'):
-            return value.split(':')
-        return [value]
-
-
-
     #------------------------------------------------------------
     # browser simulation
     #
-
-    def connect(self, url, params, ok_codes, rtype, description):
+    def _connect(self, url, params, ok_codes, rtype, description):
         """Handle fetching, logging, errors and history."""
         t_start = time.time()
         try:
             response = self._browser.fetch(url, params, ok_codes=ok_codes)
         except:
-            etype, value, tb = sys.exc_info()
+            etype, value, tback = sys.exc_info()
             t_stop = time.time()
             t_delta = t_stop - t_start
             self.total_time += t_delta
@@ -204,14 +174,14 @@ class FunkLoadTestCase(unittest.TestCase):
             self.test_status = 'Failure'
             self.logd(' Failed in %.3fs' % t_delta)
             if etype is HTTPError:
-                self.log_response(value.response, rtype, description,
-                                  t_start, t_stop, log_body=True)
-                if self.dumping:
-                    self.dump_content(value.response)
+                self._log_response(value.response, rtype, description,
+                                   t_start, t_stop, log_body=True)
+                if self._dumping:
+                    self._dump_content(value.response)
                 raise self.failureException, str(value.response)
             else:
-                self.log_response_error(url, rtype, description, t_start,
-                                        t_stop)
+                self._log_response_error(url, rtype, description, t_start,
+                                         t_stop)
                 if etype is SocketError:
                     raise SocketError("Can't load %s." % url)
                 raise
@@ -230,19 +200,27 @@ class FunkLoadTestCase(unittest.TestCase):
             self.setHeader('Referer', url)
         self._browser.history.append((rtype, url))
         self.logd(' Done in %.3fs' % t_delta)
-        self.log_response(response, rtype, description, t_start, t_stop)
-        if self.dumping:
-            self.dump_content(response)
+        self._log_response(response, rtype, description, t_start, t_stop)
+        if self._dumping:
+            self._dump_content(response)
         return response
 
-
-    def browse(self, url_in, params_in=None,
-               description=None, ok_codes=None,
-               method='post',
-               follow_redirect=True, load_auto_links=True,
-               sleep=True):
-        """Simulate a browser."""
+    def _browse(self, url_in, params_in=None,
+                description=None, ok_codes=None,
+                method='post',
+                follow_redirect=True, load_auto_links=True,
+                sleep=True):
+        """Simulate a browser handle redirects, load/cache css and images."""
         self._response = None
+        # Loop mode
+        if self._loop_mode:
+            if self.steps == self._loop_steps[0]:
+                self._loop_recording = True
+                self.logi('Loop mode start recording')
+            if self._loop_recording:
+                self._loop_records.append((url_in, params_in, description,
+                                           ok_codes, method, follow_redirect,
+                                           load_auto_links, False))
         # ok codes
         if ok_codes is None:
             ok_codes = self.ok_codes
@@ -273,7 +251,7 @@ class FunkLoadTestCase(unittest.TestCase):
                                                           self.steps,
                                                           description or ''))
         # Fetching
-        response = self.connect(url, params, ok_codes, method, description)
+        response = self._connect(url, params, ok_codes, method, description)
 
         # Check redirection
         if follow_redirect and response.code in (301, 302):
@@ -284,55 +262,79 @@ class FunkLoadTestCase(unittest.TestCase):
                 newurl = response.headers['Location']
                 url = urljoin(url_in, newurl)
                 self.logd(' Load redirect link: %s' % url)
-                response = self.connect(url, None, ok_codes, 'redirect', None)
+                response = self._connect(url, None, ok_codes, 'redirect', None)
                 max_redirect_count -= 1
             if not max_redirect_count:
                 self.logd(' WARNING Too many redirects give up.')
 
         # Load auto links (css and images)
         response.is_html = is_html(response.body)
-        if load_auto_links and response.is_html:
+        if load_auto_links and response.is_html and not self._simple_fetch:
             self.logd(' Load css and images...')
             page = response.body
             t_start = time.time()
+            c_start = self.total_time
             try:
-                # pageImages is patched to log_response on all links
+                # pageImages is patched to call _log_response on all links
                 self._browser.pageImages(url, page, self)
             except HTTPError, error:
-                t_stop = time.time()
-                t_delta = t_stop - t_start
-                self.step_success = False
-                self.test_status = 'Failure'
-                self.logd('  Failed in %.2fs' % t_delta)
-                self.log_response(error.response, 'link', None,
-                                  t_start, t_stop, log_body=True)
-                raise self.failureException, str(error)
-            t_stop = time.time()
-            self.logd('  Done in %.3fs' % (t_stop - t_start))
+                if self._accept_invalid_links:
+                    self.logd('  ' + str(error))
+                else:
+                    t_stop = time.time()
+                    t_delta = t_stop - t_start
+                    self.step_success = False
+                    self.test_status = 'Failure'
+                    self.logd('  Failed in ~ %.2fs' % t_delta)
+                    # XXX The duration logged for this response is wrong
+                    self._log_response(error.response, 'link', None,
+                                       t_start, t_stop, log_body=True)
+                    raise self.failureException, str(error)
+            c_stop = self.total_time
+            self.logd('  Done in %.3fs' % (c_stop - c_start))
         if sleep:
             self.sleep()
         self._response = response
-        return response
 
+        # Loop mode
+        if self._loop_mode and self.steps == self._loop_steps[-1]:
+            self._loop_recording = False
+            self.logi('Loop mode end recording.')
+            t_start = self.total_time
+            count = 0
+            for i in range(self._loop_number):
+                self.logi('Loop mode replay %i' % i)
+                for record in self._loop_records:
+                    count += 1
+                    self.steps += 1
+                    self._browse(*record)
+            t_delta = self.total_time - t_start
+            text = ('End of loop: %d pages rendered in %.3fs, '
+                    'avg of %.3fs per page, '
+                    '%.3f SPPS without concurrency.' % (count, t_delta,
+                                                        t_delta/count,
+                                                        count/t_delta))
+            self.logi(text)
+            trace(text + '\n')
+
+        return response
 
     def post(self, url, params=None, description=None, ok_codes=None):
         """POST method on url with params."""
         self.steps += 1
         self.page_responses = 0
-        response = self.browse(url, params, description, ok_codes,
-                               method="post")
+        response = self._browse(url, params, description, ok_codes,
+                                method="post")
         return response
 
-
     def get(self, url, params=None, description=None, ok_codes=None):
         """GET method on url adding params."""
         self.steps += 1
         self.page_responses = 0
-        response = self.browse(url, params, description, ok_codes,
-                               method="get")
+        response = self._browse(url, params, description, ok_codes,
+                                method="get")
         return response
 
-
     def exists(self, url, params=None, description="Checking existence"):
         """Try a GET on URL return True if the page exists or False."""
         resp = self.get(url, params, description=description,
@@ -343,8 +345,7 @@ class FunkLoadTestCase(unittest.TestCase):
         self.logd('Page %s exists.' % url)
         return True
 
-
-    def xmlrpc_call(self, url_in, method_name, params=None, description=None):
+    def xmlrpc(self, url_in, method_name, params=None, description=None):
         """Call an xml rpc method_name on url with params."""
         self.steps += 1
         self.page_responses = 0
@@ -365,15 +366,15 @@ class FunkLoadTestCase(unittest.TestCase):
             else:
                 response = method()
         except:
-            etype, value, tb = sys.exc_info()
+            etype, value, tback = sys.exc_info()
             t_stop = time.time()
             t_delta = t_stop - t_start
             self.total_time += t_delta
             self.step_success = False
             self.test_status = 'Error'
             self.logd(' Failed in %.3fs' % t_delta)
-            self.log_xmlrpc_response(url, method_name, description, response,
-                                     t_start, t_stop, -1)
+            self._log_xmlrpc_response(url, method_name, description, response,
+                                      t_start, t_stop, -1)
             if etype is SocketError:
                 raise SocketError("Can't access %s." % url)
             raise
@@ -382,11 +383,16 @@ class FunkLoadTestCase(unittest.TestCase):
         self.total_time += t_delta
         self.total_xmlrpc += 1
         self.logd(' Done in %.3fs' % t_delta)
-        self.log_xmlrpc_response(url, method_name, description, response,
-                                 t_start, t_stop, 200)
+        self._log_xmlrpc_response(url, method_name, description, response,
+                                  t_start, t_stop, 200)
         self.sleep()
         return response
 
+    def xmlrpc_call(self, url_in, method_name, params=None, description=None):
+        """BBB of xmlrpc, this method will be removed for 1.6.0."""
+        warn('Since 1.4.0 the method "xmlrpc_call" is renamed into "xmlrpc".',
+             DeprecationWarning, stacklevel=2)
+        return self.xmlrpc(url_in, method_name, params, description)
 
     def waitUntilAvailable(self, url, time_out=20, sleep_time=2):
         """Wait until url is available.
@@ -396,8 +402,7 @@ class FunkLoadTestCase(unittest.TestCase):
         time_start = time.time()
         while(True):
             try:
-                response = self._browser.fetch(url, None,
-                                               ok_codes=[200,301,302])
+                self._browser.fetch(url, None, ok_codes=[200, 301, 302])
             except SocketError:
                 if time.time() - time_start > time_out:
                     self.fail('Time out service %s not available after %ss' %
@@ -406,22 +411,6 @@ class FunkLoadTestCase(unittest.TestCase):
                 return
             time.sleep(sleep_time)
 
-
-    def sleep(self):
-        """Sleeps a random amount of time.
-
-        Between the predefined sleep_time_min and sleep_time_max values.
-        """
-        s_min = self.sleep_time_min
-        s_max = self.sleep_time_max
-        if s_max != s_min:
-            s_val = s_min + abs(s_max - s_min) * random()
-        else:
-            s_val = s_min
-        # we should always sleep something
-        thread_sleep(s_val)
-
-
     def setBasicAuth(self, login, password):
         """Set http basic authentication."""
         self._browser.setBasicAuth(login, password)
@@ -432,7 +421,6 @@ class FunkLoadTestCase(unittest.TestCase):
         self._browser.clearBasicAuth()
         self._authinfo = None
 
-
     def addHeader(self, key, value):
         """Add an http header."""
         self._browser.extra_headers.append((key, value))
@@ -469,6 +457,120 @@ class FunkLoadTestCase(unittest.TestCase):
         If agent is None, the user agent header is removed."""
         self.setHeader('User-Agent', agent)
 
+    def sleep(self):
+        """Sleeps a random amount of time.
+
+        Between the predefined sleep_time_min and sleep_time_max values.
+        """
+        s_min = self.sleep_time_min
+        s_max = self.sleep_time_max
+        if s_max != s_min:
+            s_val = s_min + abs(s_max - s_min) * random()
+        else:
+            s_val = s_min
+        # we should always sleep something
+        thread_sleep(s_val)
+
+
+
+    #------------------------------------------------------------
+    # Assertion helpers
+    #
+    def getLastUrl(self):
+        """Return the last accessed url taking into account redirection."""
+        response = self._response
+        if response is not None:
+            return response.url
+        return ''
+
+    def getBody(self):
+        """Return the last response content."""
+        response = self._response
+        if response is not None:
+            return response.body
+        return ''
+
+    def listHref(self, pattern=None):
+        """Return a list of href anchor url present in the last html response.
+
+        Filtering href using the pattern regex if present."""
+        response = self._response
+        ret = []
+        if response is not None:
+            a_links = response.getDOM().getByName('a')
+            if a_links:
+                ret = [getattr(x, 'href', '') for x in a_links]
+            if pattern is not None:
+                pat = re.compile(pattern)
+                ret = [href for href in ret if pat.search(href) is not None]
+        return ret
+
+    def getLastBaseUrl(self):
+        """Return the base href url."""
+        response = self._response
+        if response is not None:
+            base = response.getDOM().getByName('base')
+            if base:
+                return base[0].href
+        return ''
+
+
+    #------------------------------------------------------------
+    # configuration file utils
+    #
+    def conf_get(self, section, key, default=_marker, quiet=False):
+        """Return an entry from the options or configuration file."""
+        # check for a command line options
+        opt_key = '%s_%s' % (section, key)
+        opt_val = getattr(self.options, opt_key, None)
+        if opt_val:
+            #print('[%s] %s = %s from options.' % (section, key, opt_val))
+            return opt_val
+        # check for the configuration file if opt val is None
+        # or nul
+        try:
+            val = self._config.get(section, key)
+        except (NoSectionError, NoOptionError):
+            if not quiet:
+                self.logi('[%s] %s not found' % (section, key))
+            if default is _marker:
+                raise
+            val = default
+        #print('[%s] %s = %s from config.' % (section, key, val))
+        return val
+
+    def conf_getInt(self, section, key, default=_marker, quiet=False):
+        """Return an integer from the configuration file."""
+        return int(self.conf_get(section, key, default, quiet))
+
+    def conf_getFloat(self, section, key, default=_marker, quiet=False):
+        """Return a float from the configuration file."""
+        return float(self.conf_get(section, key, default, quiet))
+
+    def conf_getList(self, section, key, default=_marker, quiet=False):
+        """Return a list from the configuration file."""
+        value = self.conf_get(section, key, default, quiet)
+        if value is default:
+            return value
+        if value.count(':'):
+            return value.split(':')
+        return [value]
+
+
+
+    #------------------------------------------------------------
+    # Extend unittest.TestCase to provide bench cycle hook
+    #
+    def setUpCycle(self):
+        """Called on bench mode before a cycle start."""
+        pass
+
+    def tearDownCycle(self):
+        """Called after a cycle in bench mode."""
+        pass
+
+
+
     #------------------------------------------------------------
     # logging
     #
@@ -483,26 +585,26 @@ class FunkLoadTestCase(unittest.TestCase):
         else:
             print self.meta_method_name+': '+message
 
-    def logr(self, message, force=False):
+    def _logr(self, message, force=False):
         """Log a result."""
         if force or not self.in_bench_mode or recording():
             self.logger_result.info(message)
 
-    def open_result_log(self, **kw):
+    def _open_result_log(self, **kw):
         """Open the result log."""
         xml = ['<funkload version="%s" time="%s">' % (
             get_version(), datetime.now().isoformat())]
         for key, value in kw.items():
             xml.append('<config key="%s" value=%s />' % (
                 key, quoteattr(str(value))))
-        self.logr('\n'.join(xml), force=True)
+        self._logr('\n'.join(xml), force=True)
 
-    def close_result_log(self):
+    def _close_result_log(self):
         """Close the result log."""
-        self.logr('</funkload>', force=True)
+        self._logr('</funkload>', force=True)
 
-    def log_response_error(self, url, rtype, description, time_start,
-                           time_stop):
+    def _log_response_error(self, url, rtype, description, time_start,
+                            time_stop):
         """Log a response that raise an unexpected exception."""
         self.total_responses += 1
         self.page_responses += 1
@@ -524,10 +626,10 @@ class FunkLoadTestCase(unittest.TestCase):
         info['traceback'] = quoteattr(' '.join(
             traceback.format_exception(*sys.exc_info())))
         message = '''<response cycle="%(cycle).3i" cvus="%(cvus).3i" thread="%(thread_id).3i" suite="%(suite_name)s" name="%(test_name)s" step="%(step).3i" number="%(number).3i" type="%(type)s" result="%(result)s" url=%(url)s code="%(code)s" description=%(description)s time="%(time_start)s" duration="%(duration)s" traceback=%(traceback)s />''' % info
-        self.logr(message)
+        self._logr(message)
 
-    def log_response(self, response, rtype, description, time_start, time_stop,
-                     log_body=False):
+    def _log_response(self, response, rtype, description, time_start,
+                      time_stop, log_body=False):
         """Log a response."""
         self.total_responses += 1
         self.page_responses += 1
@@ -562,10 +664,10 @@ class FunkLoadTestCase(unittest.TestCase):
                 headers,
                 '  <body><![CDATA[\n%s\n]]>\n  </body>' % response.body,
                 '</response>'])
-        self.logr(message)
+        self._logr(message)
 
-    def log_xmlrpc_response(self, url, method, description, response,
-                            time_start, time_stop, code):
+    def _log_xmlrpc_response(self, url, method, description, response,
+                             time_start, time_stop, code):
         """Log a response."""
         self.total_responses += 1
         self.page_responses += 1
@@ -585,10 +687,9 @@ class FunkLoadTestCase(unittest.TestCase):
         info['duration'] = time_stop - time_start
         info['result'] = self.step_success and 'Successful' or 'Failure'
         message = '''<response cycle="%(cycle).3i" cvus="%(cvus).3i" thread="%(thread_id).3i" suite="%(suite_name)s" name="%(test_name)s" step="%(step).3i" number="%(number).3i" type="%(type)s" result="%(result)s" url=%(url)s code="%(code)s" description=%(description)s time="%(time_start)s" duration="%(duration)s" />"''' % info
-        self.logr(message)
+        self._logr(message)
 
-
-    def log_result(self, time_start, time_stop):
+    def _log_result(self, time_start, time_stop):
         """Log the test result."""
         info = {}
         info['cycle'] = self.cycle
@@ -613,14 +714,13 @@ class FunkLoadTestCase(unittest.TestCase):
         else:
             info['traceback'] = ''
         text = '''<testResult cycle="%(cycle).3i" cvus="%(cvus).3i" thread="%(thread_id).3i" suite="%(suite_name)s" name="%(test_name)s"  time="%(time_start)s" result="%(result)s" steps="%(steps)s" duration="%(duration)s" connection_duration="%(connection_duration)s" requests="%(requests)s" pages="%(pages)s" xmlrpc="%(xmlrpc)s" redirects="%(redirects)s" images="%(images)s" links="%(links)s" %(traceback)s/>''' % info
-        self.logr(text)
+        self._logr(text)
 
-
-    def dump_content(self, response):
+    def _dump_content(self, response):
         """Dump the html content in a file.
 
         Use firefox to render the content if we are in rt viewing mode."""
-        dump_dir = getattr(self.options, 'dump_dir', None)
+        dump_dir = self._dump_dir
         if dump_dir is None:
             return
         if getattr(response, 'code', 301) in [301, 302]:
@@ -634,76 +734,28 @@ class FunkLoadTestCase(unittest.TestCase):
         f = open(file_path, 'w')
         f.write(response.body)
         f.close()
-        if self.viewing:
+        if self._viewing:
             cmd = 'firefox -remote  "openfile(file://%s,new-tab)"' % file_path
             ret = os.system(cmd)
-
-    #
-    # Assertion helper
-    #
-    def getLastUrl(self):
-        """Return the last accessed url taking into account redirection."""
-        response = self._response
-        if response is not None:
-            return response.url
-        return ''
-
-    def getBody(self):
-        """Return the last response content."""
-        response = self._response
-        if response is not None:
-            return response.body
-        return ''
-
-    def listHref(self, pattern=None):
-        """Return a list of href anchor url present in the last html response.
-
-        Filtering href using the pattern regex if present."""
-        response = self._response
-        ret = []
-        if response is not None:
-            a_links = response.getDOM().getByName('a')
-            if a_links:
-                ret = [x.href for x in a_links]
-            if pattern is not None:
-                pat = re.compile(pattern)
-                ret = [href for href in ret if pat.search(href) is not None]
-        return ret
-
-    def getLastBaseUrl(self):
-        """Return the base href url."""
-        response = self._response
-        if response is not None:
-            base = response.getDOM().getByName('base')
-            if base:
-                return base[0].href
-        return ''
-
-    #
-    # extend unittest.TestCase
-    #
-    def setUpCycle(self):
-        """Called on bench mode before a cycle start."""
-        pass
-
-    def tearDownCycle(self):
-        """Called after a cycle in bench mode."""
-        pass
+            if ret != 0:
+                self.logi('Failed to remote control firefox: %s' % cmd)
+                self._viewing = False
 
 
-    #
-    # overriding unittest.TestCase
+    #------------------------------------------------------------
+    # Overriding unittest.TestCase
     #
     def __call__(self, result=None):
         """Run the test method.
 
-        Override to trace test result."""
+        Override to log test result."""
         t_start = time.time()
         if result is None:
             result = self.defaultTestResult()
         result.startTest(self)
         testMethod = getattr(self, self._TestCase__testMethodName)
         try:
+            ok = False
             try:
                 self.logd('Starting -----------------------------------\n\t%s'
                           % self.conf_get(self.meta_method_name, 'description',
@@ -714,13 +766,11 @@ class FunkLoadTestCase(unittest.TestCase):
             except:
                 result.addError(self, self._TestCase__exc_info())
                 self.test_status = 'Error'
-                self.log_result(t_start, time.time())
+                self._log_result(t_start, time.time())
                 return
-
-            ok = 0
             try:
                 testMethod()
-                ok = 1
+                ok = True
             except self.failureException:
                 result.addFailure(self, self._TestCase__exc_info())
                 self.test_status = 'Failure'
@@ -729,7 +779,6 @@ class FunkLoadTestCase(unittest.TestCase):
             except:
                 result.addError(self, self._TestCase__exc_info())
                 self.test_status = 'Error'
-
             try:
                 self.tearDown()
             except KeyboardInterrupt:
@@ -737,12 +786,13 @@ class FunkLoadTestCase(unittest.TestCase):
             except:
                 result.addError(self, self._TestCase__exc_info())
                 self.test_status = 'Error'
-                ok = 0
+                ok = False
             if ok:
                 result.addSuccess(self)
-
         finally:
-            self.log_result(t_start, time.time())
+            self._log_result(t_start, time.time())
+            if not ok and self._stop_on_fail:
+                result.stop()
             result.stopTest(self)
 
 
