@@ -15,11 +15,12 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 # 02111-1307, USA.
 #
-"""Patching Richard Jones' webunit, to :
+"""Patching Richard Jones' webunit for FunkLoad.
 
- * cache css
- * store a browser history
- * log response
+* Add cache for links (css, js)
+* store a browser history
+* add headers
+* log response
 
 $Id: PatchWebunit.py 24649 2005-08-29 14:20:19Z bdelbosc $
 """
@@ -38,6 +39,7 @@ from webunit.webunittest import HTTPResponse, HTTPError, VERBOSE
 from utils import thread_sleep
 
 class FKLIMGSucker(IMGSucker):
+    """Image and links loader, patched to log response stats."""
     def __init__(self, url, session, ftestcase=None):
         IMGSucker.__init__(self, url, session)
         self.ftestcase = ftestcase
@@ -56,8 +58,9 @@ class FKLIMGSucker(IMGSucker):
                     self.session.history.append(('image', url))
                     self.ftestcase.total_time += (t_stop - t_start)
                     self.ftestcase.total_images += 1
-                    self.ftestcase.log_response(self.session.images[url],
-                                                'image', None, t_start, t_stop)
+                    self.ftestcase._log_response(self.session.images[url],
+                                                 'image', None, t_start,
+                                                 t_stop)
                     thread_sleep()      # give a chance to other threads
             else:
                 newattributes.append((name, value))
@@ -78,8 +81,8 @@ class FKLIMGSucker(IMGSucker):
                     self.session.history.append(('link', url))
                     self.ftestcase.total_time += (t_stop - t_start)
                     self.ftestcase.total_links += 1
-                    self.ftestcase.log_response(self.session.css[url],
-                                                'link', None, t_start, t_stop)
+                    self.ftestcase._log_response(self.session.css[url],
+                                                 'link', None, t_start, t_stop)
                     thread_sleep()      # give a chance to other threads
             else:
                 newattributes.append((name, value))
